// THIS PROGRAM RUNS PROCEDURES FOR CREATING FIGURE 11, 12 and 18 
// DATE CREATED: 2025-04-25
// AUTHOR: Euijin Jung (ejung1@worldbank.org)

*************************************************************************
//////////// DATA TO GENERATE FIGURE 11, 12 AND 18 ///////////////////////////

clear all
set more off

global wb_class "$main\Data\CBAM\ISO_Region_Income.dta"
global gdp "$main\Data\CBAM\gdp.dta"

**********LOAD DATA AND IDENTIFY CBAM PRODUCTS************
import excel "$main\Data\CBAM\WITS_HS2017_Bilateral_2022.xlsx", sheet("raw_eximp") firstrow
gen product="NoCBAM"
replace product="Aluminum" if inlist( ProductCode ,7601,7603,7604,7605,7606,7607,7608,7610,7612,7614,7616) | inlist( ProductCode ,760900,761100,761300)
replace product="Cement" if inlist( ProductCode ,250700,252310,252321,252329,252330,252390)
replace product="Fertiliser" if inlist( ProductCode ,280800, 283421,310510,310520,310530,310540,310551,310559,310590)  | inlist( ProductCode ,2814,3102)
replace product="IronSteel" if inlist( ProductCode ,260112,720110,720120,720150,720211,720219,720241,720249,720260,730300, 730900, 731100)  | inlist( ProductCode ,7203,7205,7206,7207,7208,7209,7210,7211,7212,7213,7214,7215,7216,7217,7218,7219,7220,7221,7222,7223,7224,7225,7226,7227,7228,7229,7301,7302 ,7304,7305,7306,7307,7308,7310,7318,7326)
************ UPDATE ISO3*************
replace PartnerISO3="COD" if PartnerISO3=="ZAR"
replace PartnerISO3="ROU" if PartnerISO3=="ROM"
replace PartnerISO3="TWN" if PartnerISO3=="OAS"
replace PartnerISO3="SRB" if PartnerISO3=="SER"
replace PartnerISO3="TLS" if PartnerISO3=="TMP"
replace PartnerISO3="SDN" if PartnerISO3=="SUD"
replace PartnerISO3="MNE" if PartnerISO3=="MNT"
replace ReporterISO3="COD" if ReporterISO3=="ZAR"
replace ReporterISO3="ROU" if ReporterISO3=="ROM"
replace ReporterISO3="TWN" if ReporterISO3=="OAS"
replace ReporterISO3="SRB" if ReporterISO3=="SER"
replace ReporterISO3="TLS" if ReporterISO3=="TMP"
replace ReporterISO3="SDN" if ReporterISO3=="SUD"
replace ReporterISO3="MNE" if ReporterISO3=="MNT"
rename ReporterISO3 iso3
drop ReporterName PartnerName
merge m:1 iso3 using "$wb_class"
order _m
so _m iso3
keep if _m==3
drop _m
rename iso3 iso3_rep
rename PartnerI iso3
rename country country_rep
rename region region_rep
rename income income_rep
merge m:1 iso3 using "$wb_class"
order _m
so _m iso3
keep if _m==3
drop _m
rename iso3 iso3_pa
rename country country_pa
rename region region_pa
rename income income_pa

*******IDENTIFY EU MEMBERS******************************
local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
// Step 2: Generate the binary variable 'eu_member' and initialize it to 0///
gen eu_member = 0
// Step 3: Loop over each EU member code and set 'eu_member' to 1 for matches///
foreach code in `eu_members' {
    replace eu_member = 1 if iso3_rep == "`code'"
}
rename eu_member eu_rep

local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
// Step 2: Generate the binary variable 'eu_member' and initialize it to 0///
gen eu_member = 0
// Step 3: Loop over each EU member code and set 'eu_member' to 1 for matches///
foreach code in `eu_members' {
    replace eu_member = 1 if iso3_pa == "`code'"
}
rename eu_member eu_pa
tempfile tmp
save `tmp', replace


keep if TradeFlowCode==5
///1 INDICATES  IMPORTS////
drop if iso3_r=="WLD"|iso3_r=="EUN"
collapse(sum) TradeValuein1000USD, by( Nomenclature iso3_p Year product country_p region_p income_p eu_rep)
reshape wide TradeV , i( Nomenclature iso3_p Year product country_p region_p income_p)j(eu)
rename TradeValuein1000USD0 noneu
rename TradeValuein1000USD1 eu
egen wld=rowtotal(noneu eu)
format wld %13.0g
gen eu_share=eu/wld
gen source="WITS MIRROR"
rename iso3_pa iso3_rep
rename country_pa country_rep
rename region_p region_rep
rename income_p income_rep
so iso3_rep product
rename iso3_rep iso3
drop country_rep region_ income_
save "$main\Data\CBAM\mirror.dta",replace
clear


use "$main\Data\CBAM\GHG_EI_CBAM.dta"
merge m:1 iso3 product using "$main\Data\CBAM\trade output.dta"
order _m
so _m iso
drop _m
local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
gen eu_member = 0
foreach code in `eu_members' {
    replace eu_member = 1 if iso3 == "`code'"
}
so iso
tempfile temp
save `temp',replace

preserve


keep if eu_m==1
gen co2_pay=cbam_ei/10
gen output_co2=co2_p *output
so output_c
collapse(sum) output output_co2  , by( product )
gen co2_pay= output_co2 / output
rename co2_pay co2_pay_eu
gen cbam_ei_eu= co2_pay_eu*10
drop output output_co2 
merge 1:m product using `temp'
drop _m
order iso3 product scope1 scope2 cbam_ei cbam_ei_eu 
drop ghg gr
save `temp',replace
restore
///////// CALCULATION OF AVERAGE OF 3 MOST CARBON INTENSIVE EU COUNTRIES CO2 EMISSION INTENSITY ///////////////
keep if eu_m==1
keep iso3 product cbam_ei output
duplicates drop
gen co2_pay=cbam_ei/10
bysort product : egen rank=rank(-cbam_ei),track
keep if rank==1|rank==2|rank==3
collapse(mean) cbam_ei co2_pay , by( product )
rename co2_pay co2_pay_eu3
rename cbam_ei cbam_ei_eu3
merge 1:m product  using `temp'
order _m
so _m iso
drop _m

////////// CALCULATION OF EXPOSURE INDICES FOR SECTORS ////////////////////////
gen co2_pay= cbam_ei/10
merge 1:m iso product using "$main\Data\CBAM\mirror.dta"
keep if _m==3
drop _m
gen  index_trade=(co2_pay-co2_pay_eu)*eu_share

replace eu_m=2 if iso3=="NOR"| iso3=="CHE"
gen less=0
replace less=1 if eu<500
merge m:1 iso3 using "$wb_class"
order _m
so _m iso
keep if _m==3
drop _m
merge m:1 iso3 using "$gdp"
order _m
so _m iso
keep if _m==3
drop _m
so cbam_ei
save `temp', replace

////////CALCULATION OF EXPOSURE INDICES FOR AGGREGATE ////////////////////////
gen weight_eu= ( co2_pay-co2_pay_eu)*eu
gen weight=co2_pay*eu
collapse(sum) eu wld weight weight_eu   , by(country eu_member gdp iso3 income region source)
gen product="TotalCBAM"
gen index_ee=weight_eu/gdp
gen tw_co2_pay_diff=weight_eu/eu
gen co2_pay=weight/eu
gen cbam_ei=co2_pay*10
gen eu_share=eu/wld
gen eu_share_gdp=eu/gdp
label var weight_eu "sum of eu*(co2pay-co2pay_eu)"
label var weight "sum of eu*co2_pay"
gen less=0
replace less=1 if eu<1000
append using `temp'


drop eu_m
local eu_members "AUT BEL BGR HRV CYP CZE DNK EST FIN FRA DEU GRC HUN IRL ITA LVA LTU LUX MLT NLD POL PRT ROU SVK SVN ESP SWE"
gen eu_member = 0
foreach code in `eu_members' {
    replace eu_member = 1 if iso3 == "`code'"
}
replace eu_m=2 if iso3=="NOR"| iso3=="CHE"

so source less eu_member product  
format eu %13.0g
format wld %13.0g

so source eu_m less product 

label var index_t "CBAM trade exposure index"
label var index_ee "CBAM economic exposure index"
label var product "CBAM product"
label var iso3 "iso3"
label variable eu_member "2=efta; 1=eu; 0;non-eu"
label variable eu "export to EU (USD1000)"
label variable wld "export to world (USD1000)"
label variable scope1 "CO2 emission intensity scope 1 (KG/USD)"
label variable scope2 "CO2 emission intensity scope 2 (KG/USD)"
label var eu_share "Export to EU as share of export to world"
label variable less "1=export value less than USD 0.5m for sector or USD 1m for total"
label variable eu_share_gdp "export to EU as share of GDP"
label var cbam_ei "carbon emission intensity (KG/USD)"
label var cbam_ei_eu "output weighted average of EU emission intensity (KG/USD)"
label var gdp "GDP (USD1000)"


so eu_member less source product 
tempfile raw
save `raw',replace


////////////////// PRODUCTION OF CHARTS IN THE PAPER /////////////////////////////

preserve

keep if eu_m==0&less==0
drop if income=="High income"
bysort product: egen rank_ee=rank(-index_ee),track
bysort product: egen rank_t=rank(-index_t),track
bysort product: egen rank_t2=rank(index_t),track

order product country  index_trade rank_t  index_ee  rank_ee eu wld tw_co2_pay_diff co2_pay co2_pay_eu eu_share_gdp wld_share
gen eu_share2=eu_share*wld_share*100
replace eu_share=100* eu_share
replace co2_pay=co2_pay*100
replace co2_pay_eu=co2_pay_eu*100
replace co2_pay_eu3=co2_pay_eu3*100
replace index_t= index_t*100
replace index_ee= index_ee*100

tempfile temp
save `temp',replace
drop if product=="TotalCBAM"
keep product country index_trade rank_t rank_t2 iso3 eu_share co2_pay co2_pay_eu co2_pay_eu3
order product country index_trade rank_t rank_t2 iso3 eu_share co2_pay co2_pay_eu co2_pay_eu3
keep if rank_t<8|rank_t2<4
drop rank_t2
label var index_t "CBAM trade exposure index (%)"
label var product "CBAM product"
label var iso3 "iso3"
label var eu_share "Export to EU as % of export to world"
label var co2_pay "carbon emission payment (%)"
label var co2_pay_eu "EU average carbon emission payment (%)"
label var co2_pay_eu3 "3 most carbon  intensive EU countries average carbon emission payment (%)"
so product rank_t
save "$main\Output\fig11.dta",replace

clear
use `temp'
keep if product=="TotalCBAM"
keep product country index_ee rank_ee 
keep if rank_ee<11
so rank_ee
label var index_ee "Economic Exposure Index (%)"
label var product "CBAM product"
save "$main\Output\fig12.dta",replace
restore
clear




/////////////////// DATA TO GENERATE FIGURE 18 /////////////////////

clear
use `temp'
keep if product=="TotalCBAM"
keep product country index_ee rank_ee 
tempfile ee
save `ee',replace
clear
global wb_class "$main\Data\CBAM\ISO_Region_Income.dta"
import excel "$main\Data\CBAM\carbon price.xlsx", sheet("Sheet1") firstrow
keep Jurisdictioncovered Type usprice2024
rename Ju country
drop if missing(us)
merge m:1 country using `ee'
so rank
keep if rank<21
drop _m
lab var Type "type of instrument"
lab var country "country"
lab var us "Carbon Price (USD)"
lab var index "Economic Exposure Index (% of GDP)"
lab var rank "Rank of Index"
save "$main\Output\fig18.dta",replace

clear
